@@ -18,13 +18,15 @@ import static org.mockito.Mockito.when;
 import static org.testng.Assert.*;
 
 import io.fabric8.kubernetes.api.model.ObjectMeta;
+import io.fabric8.kubernetes.client.KubernetesClientException;
 import io.fabric8.openshift.api.model.User;
 import io.fabric8.openshift.client.OpenShiftClient;
+import jakarta.servlet.FilterChain;
+import jakarta.servlet.ServletException;
+import jakarta.servlet.http.HttpServletRequest;
+import jakarta.servlet.http.HttpServletResponse;
 import java.io.IOException;
-import javax.servlet.FilterChain;
-import javax.servlet.ServletException;
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
+import java.util.Optional;
 import org.eclipse.che.api.core.ConflictException;
 import org.eclipse.che.api.core.ServerException;
 import org.eclipse.che.api.user.server.UserManager;
@@ -77,8 +79,10 @@ public class OpenshiftTokenInitializationFilterTest {
     when(openshiftUser.getMetadata()).thenReturn(openshiftUserMeta);
     when(openshiftUserMeta.getUid()).thenReturn(USER_UID);
 
-    String userId = openshiftTokenInitializationFilter.getUserId(TOKEN);
+    User u = openshiftTokenInitializationFilter.processToken(TOKEN).get();
+    String userId = openshiftTokenInitializationFilter.getUserId(u);
 
+    assertEquals(u, openshiftUser);
     assertEquals(userId, USER_UID);
     verify(openShiftClientFactory).createAuthenticatedClient(TOKEN);
     verify(openShiftClient).currentUser();
@@ -98,14 +102,15 @@ public class OpenshiftTokenInitializationFilterTest {
         .thenReturn(
             new UserImpl(KUBE_ADMIN_USERNAME, KUBE_ADMIN_USERNAME + "@che", KUBE_ADMIN_USERNAME));
 
-    Subject subject = openshiftTokenInitializationFilter.extractSubject(TOKEN);
+    User u = openshiftTokenInitializationFilter.processToken(TOKEN).get();
+    Subject subject = openshiftTokenInitializationFilter.extractSubject(TOKEN, u);
 
     assertEquals(subject.getUserId(), KUBE_ADMIN_USERNAME);
     assertEquals(subject.getUserName(), KUBE_ADMIN_USERNAME);
   }
 
   @Test
-  public void extractSubjectCreatesSubjectWithCurretlyAuthenticatedUser()
+  public void extractSubjectCreatesSubjectWithCurrentlyAuthenticatedUser()
       throws InfrastructureException, ServerException, ConflictException {
     when(openShiftClientFactory.createAuthenticatedClient(TOKEN)).thenReturn(openShiftClient);
     when(openShiftClient.currentUser()).thenReturn(openshiftUser);
@@ -115,8 +120,10 @@ public class OpenshiftTokenInitializationFilterTest {
     when(userManager.getOrCreateUser(USER_UID, USERNAME + "@che", USERNAME))
         .thenReturn(new UserImpl(USER_UID, USERNAME + "@che", USERNAME));
 
-    Subject subject = openshiftTokenInitializationFilter.extractSubject(TOKEN);
+    User u = openshiftTokenInitializationFilter.processToken(TOKEN).get();
+    Subject subject = openshiftTokenInitializationFilter.extractSubject(TOKEN, u);
 
+    assertEquals(u, openshiftUser);
     assertEquals(subject.getUserId(), USER_UID);
     assertEquals(subject.getUserName(), USERNAME);
   }
@@ -141,4 +148,14 @@ public class OpenshiftTokenInitializationFilterTest {
 
     verify(servletResponse).sendError(eq(401), anyString());
   }
+
+  @Test
+  public void invalidTokenShouldBeHandledAsMissing() throws Exception {
+    when(openShiftClientFactory.createAuthenticatedClient(TOKEN)).thenReturn(openShiftClient);
+    when(openShiftClient.currentUser())
+        .thenThrow(new KubernetesClientException("failah", 401, null));
+
+    Optional<User> u = openshiftTokenInitializationFilter.processToken(TOKEN);
+    assertTrue(u.isEmpty());
+  }
 }
