@@ -39,9 +39,9 @@ import com.google.inject.Stage;
 import com.google.inject.multibindings.MapBinder;
 import com.google.inject.multibindings.Multibinder;
 import com.google.inject.name.Names;
+import jakarta.annotation.PostConstruct;
 import java.util.Map;
 import java.util.concurrent.Callable;
-import javax.annotation.PostConstruct;
 import javax.inject.Singleton;
 import javax.persistence.EntityManagerFactory;
 import org.eclipse.che.account.api.AccountManager;
